@@ -636,7 +636,7 @@ class BaseProject:
     def search_standard(
         self,
         val_metric : str = 'val/acc'
-    )->Tuple["np.ndarray", dict[str,int], dict[str,int]]: 
+    )->Tuple["np.ndarray", Dict[str,int], Dict[str,int]]: 
         r"""Search method for finding the model type/structure with best validation performance.
 
         Args:
