@@ -8,7 +8,7 @@ from torch import Tensor
 import matplotlib.pyplot as plt
 from torchmetrics import AUROC
 from torchmetrics.functional import dice_score
-from typing import Union, List, Dict, Any, Optional
+from typing import Union, List, Dict, Any, Optional, Tuple
 
 def column_or_1d(y):
     y = torch.as_tensor(y)
